==> haskell-vector-th-unbox-0.2.2-459-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-th-unbox
version:              0.2.2
visibility:           public
id:                   vector-th-unbox-0.2.2-9crWW7oYHyFKZju0qn9iNI
key:                  vector-th-unbox-0.2.2-9crWW7oYHyFKZju0qn9iNI
license:              BSD-3-Clause
copyright:            (c) 2012-2015 Liyang HU
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Liyang HU <vector-th-unbox@liyang.hu>
stability:            experimental
homepage:             https://github.com/tsurucapital/vector-th-unbox
synopsis:             Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.

    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.

category:             Data
abi:                  a3b4d973b05b6bb1e4901f2f89bdd28e
exposed:              True
exposed-modules:      Data.Vector.Unboxed.Deriving
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-th-unbox-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-th-unbox-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-th-unbox-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-th-unbox
hs-libraries:         HSvector-th-unbox-0.2.2-9crWW7oYHyFKZju0qn9iNI
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    vector-0.13.2.0-9T4r6UIrkEUFNE8K3nqJNe

haddock-interfaces:
    /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock

haddock-html:         /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.2-461-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-th-unbox
version:              0.2.2
visibility:           public
id:                   vector-th-unbox-0.2.2-ECttW9Ebn2VGW1P669CvHZ
key:                  vector-th-unbox-0.2.2-ECttW9Ebn2VGW1P669CvHZ
license:              BSD-3-Clause
copyright:            (c) 2012-2015 Liyang HU
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Liyang HU <vector-th-unbox@liyang.hu>
stability:            experimental
homepage:             https://github.com/tsurucapital/vector-th-unbox
synopsis:             Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.

    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.

category:             Data
abi:                  f7b065dc9e274c6fc0e83942d1ee9145
exposed:              True
exposed-modules:      Data.Vector.Unboxed.Deriving
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-th-unbox-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-th-unbox-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-th-unbox-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-th-unbox
hs-libraries:         HSvector-th-unbox-0.2.2-ECttW9Ebn2VGW1P669CvHZ
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U

haddock-interfaces:
    /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock

haddock-html:         /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
